Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS CodePipeline.

Actions, resources, and condition keys for AWS CodePipeline - Service Authorization Reference

# Actions, resources, and condition keys for AWS CodePipeline

AWS CodePipeline (service prefix: `codepipeline` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS CodePipeline
- Resource types defined by AWS CodePipeline
- Condition keys for AWS CodePipeline

## Actions defined by AWS CodePipeline

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AcknowledgeJob | Grants permission to view information about a specified job and whether that job has been received by the job worker | Write |  |  |
AcknowledgeThirdPartyJob | Grants permission to confirm that a job worker has received the specified job (partner actions only) | Write |  |  |
CreateCustomActionType | Grants permission to create a custom action that you can use in the pipelines associated with your AWS account | Write | actiontype* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreatePipeline | Grants permission to create a uniquely named pipeline | Write | pipeline* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteCustomActionType | Grants permission to delete a custom action | Write | actiontype* |  |
DeletePipeline | Grants permission to delete a specified pipeline | Write | pipeline* |  |
DeleteWebhook | Grants permission to delete a specified webhook | Write | webhook* |  |
DeregisterWebhookWithThirdParty | Grants permission to remove the registration of a webhook with the third party specified in its configuration | Write | webhook* |  |
DisableStageTransition | Grants permission to prevent revisions from transitioning to the next stage in a pipeline | Write | stage* |  |
EnableStageTransition | Grants permission to allow revisions to transition to the next stage in a pipeline | Write | stage* |  |
GetActionType | Grants permission to view information about an action type | Read |  |  |
GetJobDetails | Grants permission to view information about a job (custom actions only) | Read |  |  |
GetPipeline | Grants permission to retrieve information about a pipeline structure | Read | pipeline* |  |
GetPipelineExecution | Grants permission to view information about an execution of a pipeline, including details about artifacts, the pipeline execution ID, and the name, version, and status of the pipeline | Read | pipeline* |  |
GetPipelineState | Grants permission to view information about the current state of the stages and actions of a pipeline | Read | pipeline* |  |
GetThirdPartyJobDetails | Grants permission to view the details of a job for a third-party action (partner actions only) | Read |  |  |
ListActionExecutions | Grants permission to list the action executions that have occurred in a pipeline | Read | pipeline* |  |
ListActionTypes | Grants permission to list a summary of all the action types available for pipelines in your account | Read |  |  |
ListPipelineExecutions | Grants permission to list a summary of the most recent executions for a pipeline | List | pipeline* |  |
ListPipelines | Grants permission to list a summary of all the pipelines associated with your AWS account | List |  |  |
ListTagsForResource | Grants permission to list tags for a CodePipeline resource | Read | actiontype |  |
pipeline |  |
webhook |  |
ListWebhooks | Grants permission to list all of the webhooks associated with your AWS account | List | webhook* |  |
PollForJobs | Grants permission to view information about any jobs for CodePipeline to act on | Write | actiontype* |  |
PollForThirdPartyJobs | Grants permission to determine whether there are any third-party jobs for a job worker to act on (partner actions only) | Write |  |  |
PutActionRevision | Grants permission to edit actions in a pipeline | Write | action* |  |
PutApprovalResult | Grants permission to provide a response (Approved or Rejected) to a manual approval request in CodePipeline | Write | action* |  |
PutJobFailureResult | Grants permission to represent the failure of a job as returned to the pipeline by a job worker (custom actions only) | Write |  |  |
PutJobSuccessResult | Grants permission to represent the success of a job as returned to the pipeline by a job worker (custom actions only) | Write |  |  |
PutThirdPartyJobFailureResult | Grants permission to represent the failure of a third-party job as returned to the pipeline by a job worker (partner actions only) | Write |  |  |
PutThirdPartyJobSuccessResult | Grants permission to represent the success of a third-party job as returned to the pipeline by a job worker (partner actions only) | Write |  |  |
PutWebhook | Grants permission to create or update a webhook | Write | pipeline* |  |
webhook* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
RegisterWebhookWithThirdParty | Grants permission to register a webhook with the third party specified in its configuration | Write | webhook* |  |
RetryStageExecution | Grants permission to resume the pipeline execution by retrying the last failed actions in a stage | Write | stage* |  |
StartPipelineExecution | Grants permission to run the most recent revision through the pipeline | Write | pipeline* |  |
StopPipelineExecution | Grants permission to stop an in-progress pipeline execution | Write | pipeline* |  |
TagResource | Grants permission to tag a CodePipeline resource | Tagging | actiontype |  |
pipeline |  |
webhook |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove a tag from a CodePipeline resource | Tagging | actiontype |  |
pipeline |  |
webhook |  |
| aws:TagKeys |
UpdateActionType | Grants permission to update an action type | Write | actiontype* |  |
UpdatePipeline | Grants permission to update a pipeline with changes to the structure of the pipeline | Write | pipeline* |  |

## Resource types defined by AWS CodePipeline

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
action | `arn:$ { Partition}:codepipeline:$ { Region}:$ { Account}:$ { PipelineName}/$ { StageName}/$ { ActionName}` | aws:ResourceTag/${TagKey}
actiontype | `arn:$ { Partition}:codepipeline:$ { Region}:$ { Account}:actiontype:$ { Owner}/$ { Category}/$ { Provider}/$ { Version}` | aws:ResourceTag/${TagKey}
pipeline | `arn:$ { Partition}:codepipeline:$ { Region}:$ { Account}:$ { PipelineName}` | aws:ResourceTag/${TagKey}
stage | `arn:$ { Partition}:codepipeline:$ { Region}:$ { Account}:$ { PipelineName}/$ { StageName}` | aws:ResourceTag/${TagKey}
webhook | `arn:$ { Partition}:codepipeline:$ { Region}:$ { Account}:webhook:$ { WebhookName}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS CodePipeline

AWS CodePipeline defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters actions based on the presence of tag keys in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.